EventInfo

Struct EventInfo 

pub struct EventInfo {
    pub event: input_event,
    pub event_us: u64,
    pub is_bounce: bool,
    pub diff_us: Option<u64>,
    pub last_passed_us: Option<u64>,
}
Detailed information about a single processed event, sent to the logger.

Fields

event: input_event

The raw input event.

event_us: u64

Timestamp of the event in microseconds.

is_bounce: bool

Result of the bounce check (true if bounced/dropped).

diff_us: Option<u64>

Time difference (µs) between this event and the previous passed event of the same type, only if is_bounce is true.

last_passed_us: Option<u64>

Timestamp (µs) of the previous event of the same type that passed the filter. This is needed by the logger thread to calculate near-miss statistics.