Module cli
intercept_
bounce
0.9.1
Module cli
Module Items
Structs
Functions
In crate intercept_
bounce
intercept_bounce
Module
cli
Structs

Args
An Interception Tools filter to eliminate keyboard chatter (switch bounce). Reads Linux input events from stdin, filters rapid duplicate key events, and writes the filtered events to stdout. Statistics are printed to stderr on exit.
Functions

parse_
args